@@ -1,7 +1,9 @@
 
 // We need to define this here to reach RcppExports.cpp
-// TileDB 2.14.0 or later no longer need it
-#define TILEDB_DEPRECATED
+// TileDB 2.15.0 or later no longer need it
+#if defined(TILEDB_SILENT_BUILD)
+  #define TILEDB_DEPRECATED
+#endif
 
 #include <tiledb/tiledb>
 #if TILEDB_VERSION_MAJOR == 2 && TILEDB_VERSION_MINOR >= 4
@@ -16,6 +18,12 @@
 #define RCPP_USE_FINALIZE_ON_EXIT
 #include "Rcpp.h"
 
+#include "tinyspdl.h"
+#include "column_buffer.h"
+#include "array_buffers.h"
+
+#include "nanoarrow.h"
+
 #ifndef __tiledb_h__
 #define __tiledb_h__
 
@@ -27,6 +35,7 @@ struct var_length_char_buffer {
     int32_t rows, cols;              	// dimension from subarray
     bool nullable;                      // flag
     std::vector<uint8_t> validity_map;  // for nullable vectors
+    bool legacy_validity;               // for legacy validity mode
 };
 typedef struct var_length_char_buffer vlc_buf_t;
 
@@ -55,6 +64,10 @@ struct query_buffer {
 };
 typedef struct query_buffer query_buf_t;
 
+// map from buffer names to shared_ptr to column_buffer
+typedef std::unordered_map<std::string, std::shared_ptr<tiledb::ColumnBuffer>> map_to_col_buf_t;
+
+
 // C++ compiler complains about missing delete functionality when we use tiledb_vfs_fh_t directly
 struct vfs_fh {
    void *fh;
